.. pyearth documentation master file, created by
   sphinx-quickstart.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyearth documentation!
==============================================

Contents:

.. toctree::
   :maxdepth: 2

   story
   getting-started
   algorithm/gis/gis.rst
   algorithm/system/system.rst
   algorithm/toolbox/toolbox.rst
   algorithm/visual/visual.rst
   algorithm/api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
